@@ -21,7 +21,7 @@ our %EXPORT_TAGS = ( 'all' => \@EXPORT_OK, );
 sub _CERTIFICATE_HEADER_SIZE { return 40; }
 sub _MAX_PUBLIC_KEY_SIZE     { return 65_536; }
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 sub pin_sha256 {
     my ($path) = @_;
@@ -184,7 +184,7 @@ HTTP::PublicKeyPins - Generate RFC 7469 HTTP Public Key Pin (HPKP) header values
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =head1 SYNOPSIS
 
@@ -211,7 +211,7 @@ This module allows the calculation of RFC 7469 HTTP Public Key Pin header values
 
 =head2 pin_sha256
 
-This function accepts the path to a L<X.509 Certificate|http://tools.ietf.org/html/rfc5280>.  It will load the public key from the certificate and prepare the appropriate value for the pin_sha256 parameter of the Public-Key-Pins value. This function will also make an attempt to read public keys (in PEM (L<SubjectPublicKeyInfo|http://tools.ietf.org/html/rfc5280#section-4.1.2.7> or L(PKCS#1|https://tools.ietf.org/html/rfc344) or DER format).
+This function accepts the path to a L<X.509 Certificate|http://tools.ietf.org/html/rfc5280>.  It will load the public key from the certificate and prepare the appropriate value for the pin_sha256 parameter of the Public-Key-Pins value. This function will also make an attempt to read public keys (in PEM (L<SubjectPublicKeyInfo|http://tools.ietf.org/html/rfc5280#section-4.1.2.7> or L<PKCS#1|https://tools.ietf.org/html/rfc344> or DER format).
 
 =head1 SUBROUTINES/METHODS
 
